#
# spec file for package knights
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without lang
Name:           knights
Version:        20.04.2
Release:        lp152.1.1
Summary:        A simple chess board
License:        GPL-2.0-or-later
Group:          Amusements/Games/Board/Chess
URL:            https://www.kde.org
Source:         https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
BuildRequires:  extra-cmake-modules
BuildRequires:  cmake(KF5ConfigWidgets)
BuildRequires:  cmake(KF5Crash)
BuildRequires:  cmake(KF5DBusAddons)
BuildRequires:  cmake(KF5DocTools)
BuildRequires:  cmake(KF5KDEGames)
BuildRequires:  cmake(KF5KIO)
BuildRequires:  cmake(KF5Plasma)
BuildRequires:  cmake(KF5Plotting)
BuildRequires:  cmake(KF5TextWidgets)
BuildRequires:  cmake(KF5Wallet)
BuildRequires:  cmake(KF5XmlGui)
BuildRequires:  cmake(Qt5Concurrent)
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5Svg)
BuildRequires:  cmake(Qt5TextToSpeech)
BuildRequires:  cmake(Qt5Widgets)
Requires:       gnuchess
Recommends:     %{name}-lang
Suggests:       crafty
Obsoletes:      kchess
%if %{with lang}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
%if 0%{?suse_version}
BuildRequires:  update-desktop-files
%endif

%description
Knights is KDE's chess frontend. It supports playing local games against
human players or against chess engines (XBoard and UIC),
as well as playing online games on FICS server.
Furthermore, it is possible to watch two different chess engines playing
against each other.

%lang_package

%prep
%setup -q

%build
%cmake_kf5 -d build
%cmake_build

%install
%kf5_makeinstall -C build

%if 0%{?suse_version}
%suse_update_desktop_file -r org.kde.knights Qt KDE Game BoardGame
%endif

%if %{with lang}
%find_lang %{name}
%{kf5_find_htmldocs}
%endif

%files
%license LICENSE
%doc README.themes
%{_kf5_applicationsdir}/org.kde.knights.desktop
%{_kf5_appstreamdir}/org.kde.knights.appdata.xml
%{_kf5_bindir}/knights
%{_kf5_configdir}/knights.knsrc
%dir %{_kf5_configkcfgdir}
%{_kf5_configkcfgdir}/knights.kcfg
%{_kf5_dbusinterfacesdir}/org.kde.Knights.xml
%{_kf5_debugdir}/knights.categories
%doc %{_kf5_htmldir}/en/knights/
%{_kf5_iconsdir}/*/*/*/knights.*
%{_kf5_kxmlguidir}/knights/
%{_kf5_sharedir}/knights/

%if %{with lang}
%files lang -f %{name}.lang
%endif

%changelog
* Tue Jun  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-06-apps-update
- No code change since 20.04.1
* Fri May 15 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-05-apps-update
- No code change since 20.04.0
* Thu Apr 23 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-04-apps-update
- Changes since 20.03.90:
  * Fix build with Qt >= 5.15.0-beta3
* Sun Apr  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.90
  * New feature release
- No code change since 20.03.80
* Sun Mar 22 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.80
  * New feature release
- Changes since 19.12.3:
  * Port deprecated signal (qt5.15)
  * Use safe hardcoded value for ProvidersUrl
  * Use the default address for KNewStuff instead of the hardcoded
  * Use https://autoconfig.kde.org/ as requested
  * It alreadys added by kaboutdata
  * Make it compile against qt5.15
  * Don't use nullptr for flags
  * Use URLs with transport encryption
* Thu Mar  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-03-apps-update
- No code change since 19.12.2
* Fri Feb  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Wed Feb  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-02-apps-update
- No code change since 19.12.1
* Tue Jan  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12.1
- No code change since 19.12.0
* Tue Dec 10 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12
- No code change since 19.11.90
* Sat Nov 30 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/19.12-rc
- No code change since 19.11.80
* Sun Nov 24 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.80
  * New feature release
- Changes since 19.08.3:
  * Make it compiles without kf5 deprecated methods
  * Add Icon to Executable and Restrict GNUCXX compiler options
  * Show the notification in the status bar when the current player is thinking longer than one second. (kde#412658)
* Thu Nov  7 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.3.php
- No code change since 19.08.2
* Fri Oct 11 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.2.php
- Changes since 19.08.1:
  * Fix problem starting games when second player is computer engine (kde#411825)
* Thu Sep  5 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.1.php
- No code change since 19.08.0
* Fri Aug  9 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.0.php
- No code change since 19.07.90
* Tue Aug  6 2019 lbeltrame@kde.org
- Update to 19.07.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-rc.php
- No code changes since 19.07.80
* Tue Jul 23 2019 lbeltrame@kde.org
- Update to 19.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-beta.php
- Changes since 19.04.3:
  * Remove unused includes
  * Use new logging category directory when ECM>=5.59
  * It compiles fine without foreach + it compiles without deprecated method
  * only one default
  * new default with simple screenshot and default theme
* Sat Jul 13 2019 lbeltrame@kde.org
- Update to 19.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.3.php
- No code changes since 19.04.2
* Fri Jun  7 2019 lbeltrame@kde.org
- Update to 19.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.2.php
- No code changes since 19.04.1
* Fri May 10 2019 lbeltrame@kde.org
- Update to 19.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.1.php
- Changes since 19.04.0:
  * No code changes since 19.04.0
* Sat Apr 20 2019 lbeltrame@kde.org
- Update to 19.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.0.php
- Changes since 19.03.90:
  * No code changes since 19.03.90
* Tue Apr  9 2019 lbeltrame@kde.org
- Update to 19.03.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-rc.php
- Changes since 19.03.80:
  * Don't crash when new game is created. Regression introduced in 8867833e00bdca2373a0b6ad9a4431d184501691. (kde#405763)
* Wed Mar 27 2019 lbeltrame@kde.org
- Update to 19.03.80
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-beta.php
- Changes since 18.12.3:
  * Clean up for making asan happy when we close apps
  * not necessary to check pointer before deleting it
  * Fix build by adding missing header.
* Sat Mar  9 2019 lbeltrame@kde.org
- Update to 18.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.3.php
- Changes since 18.12.2:
  * No code changes since 18.12.2
* Sat Feb  9 2019 lbeltrame@kde.org
- Update to 18.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.2.php
- Changes since 18.12.1:
  * No code changes since 18.12.1
* Fri Jan 11 2019 lbeltrame@kde.org
- Update to 18.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.1.php
- Changes since 18.12.0:
  * No code changes since 18.12.0
* Fri Dec 14 2018 lbeltrame@kde.org
- Update to 18.12.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.0.php
- Changes since 18.11.90:
  * Delay creation of QTextToSpeech
  * Fix build by adding missing header.
* Fri Nov 30 2018 wbauer@tmo.at
- Update to 18.11.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-rc.php
- Changes since 18.11.80:
  * Add LICENSE (GPL-2.0)
* Fri Nov 23 2018 wbauer@tmo.at
- Update to 18.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-beta.php
- Changes since 2.5.0:
  * Ported to Qt5 and KDE Frameworks 5
- Updated URL and package summary/description
* Fri Aug 24 2012 mailaender@opensuse.org
- update to 2.5.0
  + Port to new KDEGames library, compatible with KDE 4.9
* Sat Apr 21 2012 alinm.elena@gmail.com
- updated to 2.4.2
  +A handful of usability fixes
  +introduces support for the UCI protocol, setting the difficulty level of chess engines, game history display, and loading and saving PGN files.
  +brings voice support, possibility of external control by dbus, and a couple of bug fixes.
  +bugfix release with several fixes, mostly by Dave Kaye. It fixes drag-coused freezes, dropping pieces outside of the board, and a theme appearing twice in the selection dialog.
  +the peace captured by en-passant is now properly removed.
    +Watching two engines play
  +Improved time control support for chess engines
  +Better support for the XBoard protocol means Knights can play with more engines, including Crafty, Sloppy, Sjeng and Phalanx.
  +Players can now make and receive offer for draw, pause, undo, adjourn and abort. All except Draw are only used when playing on the chess server.
  +Players can now undo their moves.
  +Improved game dialog, with more game options.
  +Improved server dialog, with a seek graph.
  +Ability to interact with a chess server or a computer engine via a text console.
  +Simple chat widget for talking to your remote opponent.
  +Selecting and moving pieces by clicking, without dragging.
* Wed Jan 18 2012 tittiatcoke@gmail.com
- Update to version 2.4.1
  * Support for the UCI protocol
  * Setting the difficulty level of chess engines
  * Game history display
  * Loading and saving PGN files
* Fri Oct 21 2011 asterios.dramis@gmail.com
- Update to version 2.4.0:
  * Voice support.
  * Possibility of external control by dbus.
  * Bug fixes.
- Spec file updates:
  * Changes based on spec-cleaner run.
  * Changed License: to GPL-2.0+ (which is the package's main license).
* Sat May 21 2011 bitshuffler@opensuse.org
- Update to version 2.3.2
* Sat Mar 19 2011 asterios.dramis@gmail.com
- Update to version 2.3.1:
  * Fix bug; the peace captured by en-passant is now properly removed.
- Spec file updates:
  * Changed License: to GPLv2+ and GFDL.
  * Recommend instead of Suggest for knights-lang package.
  * Added crafty Suggests: entry.
  * Updated %%description.
  * Minor other updates.
* Thu Mar 10 2011 bitshuffler@opensuse.org
- Update to version 2.3.0
* Fri Jan 21 2011 asterios.dramis@gmail.com
- Spec file updates:
  * Updates in Group:, BuildRequires: and %%install sections.
  * Remove some locales to fix rpmlint warning (invalid-lc-messages-dir) in
    openSUSE 11.3 and build error in openSUSE Factory.
* Tue Jan 11 2011 asterios.dramis@gmail.com
- Update to version 2.2.0
  * First release from Extragear, improved FICS support, nicer look and feel.
  From 2.1.1
  * Pawn promotion, theme download from kde-look.org.
- Spec file updates:
  * Added a knights-lang package.
  * Changes based on rpmdevtools templates and spec-cleaner run.
  * Updates in BuildRequires: and %%install sections.
* Fri Aug 27 2010 tittiatcoke@gmail.com
- update to version 2.1.0
  * Internet play, additional markers, graphical clock.
* Mon May 10 2010 tittiatcoke@gmail.com
- Update to version 2.0.1
  * Optional clocks and time limits
  * Uses the old Knights icons
* Sat Apr 10 2010 tittiatcoke@gmail.com
- initial release, version 2.0
